==> puppet-module-puppetlabs-rabbitmq_5.3.1.orig.tar.xz: puppet-module-puppetlabs-rabbitmq-5.3.1/spec/acceptance/clustering_spec.rb <==
require 'spec_helper_acceptance'

describe 'rabbitmq clustering' do
  context 'rabbitmq::wipe_db_on_cookie_change => false' do
    it 'should run successfully' do
      pp = <<-EOS
      class { 'rabbitmq': 
        config_cluster           => true,
        cluster_nodes            => ['rabbit1', 'rabbit2'],
        cluster_node_type        => 'ram',
        erlang_cookie            => 'TESTCOOKIE',
        wipe_db_on_cookie_change => false,
      }
      if $::osfamily == 'RedHat' {
        class { 'erlang': epel_enable => true}
        Class['erlang'] -> Class['rabbitmq']
      }
      EOS

      apply_manifest(pp, :expect_failures => true)
    end

    describe file('/var/lib/rabbitmq/.erlang.cookie') do
      it { should_not contain 'TESTCOOKIE' }
    end

  end
  context 'rabbitmq::wipe_db_on_cookie_change => true' do
    it 'should run successfully' do
      pp = <<-EOS
      class { 'rabbitmq': 
        config_cluster           => true,
        cluster_nodes            => ['rabbit1', 'rabbit2'],
        cluster_node_type        => 'ram',
        erlang_cookie            => 'TESTCOOKIE',
        wipe_db_on_cookie_change => true,
      }
      if $::osfamily == 'RedHat' {
        class { 'erlang': epel_enable => true}
        Class['erlang'] -> Class['rabbitmq']
      }
      EOS

      apply_manifest(pp, :catch_failures => true)
    end

    describe file('/etc/rabbitmq/rabbitmq.config') do
      it { should be_file }
      it { should contain 'cluster_nodes' }
      it { should contain 'rabbit@rabbit1' }
      it { should contain 'rabbit@rabbit2' }
      it { should contain 'ram' }
    end

    describe file('/var/lib/rabbitmq/.erlang.cookie') do
      it { should be_file }
      it { should contain 'TESTCOOKIE' }
    end
  end
end

==> puppet-module-puppetlabs-rabbitmq_8.5.0.orig.tar.xz: puppet-module-puppetlabs-rabbitmq-8.5.0/spec/acceptance/clustering_spec.rb <==
require 'spec_helper_acceptance'

describe 'rabbitmq clustering' do
  context 'rabbitmq::wipe_db_on_cookie_change => false' do
    it 'runs successfully' do
      pp = <<-EOS
      class { 'rabbitmq':
        config_cluster           => true,
        cluster_nodes            => ['rabbit1', 'rabbit2'],
        cluster_node_type        => 'ram',
        erlang_cookie            => 'TESTCOOKIE',
        wipe_db_on_cookie_change => false,
      }
      if $facts['os']['family'] == 'RedHat' {
        class { 'erlang': epel_enable => true}
        Class['erlang'] -> Class['rabbitmq']
      }
      EOS

      apply_manifest(pp, expect_failures: true)
    end

    describe file('/var/lib/rabbitmq/.erlang.cookie') do
      it { is_expected.not_to contain 'TESTCOOKIE' }
    end
  end
  context 'rabbitmq::wipe_db_on_cookie_change => true' do
    it 'runs successfully' do
      pp = <<-EOS
      class { 'rabbitmq':
        config_cluster           => true,
        cluster_nodes            => ['rabbit1', 'rabbit2'],
        cluster_node_type        => 'ram',
        erlang_cookie            => 'TESTCOOKIE',
        wipe_db_on_cookie_change => true,
      }
      if $facts['os']['family'] == 'RedHat' {
        class { 'erlang': epel_enable => true}
        Class['erlang'] -> Class['rabbitmq']
      }
      EOS

      apply_manifest(pp, catch_failures: true)
    end

    describe file('/etc/rabbitmq/rabbitmq.config') do
      it { is_expected.to be_file }
      it { is_expected.to contain 'cluster_nodes' }
      it { is_expected.to contain 'rabbit@rabbit1' }
      it { is_expected.to contain 'rabbit@rabbit2' }
      it { is_expected.to contain 'ram' }
    end

    describe file('/var/lib/rabbitmq/.erlang.cookie') do
      it { is_expected.to be_file }
      it { is_expected.to contain 'TESTCOOKIE' }
    end
  end
end
